@@ -758,15 +758,17 @@ class NoDescriptionValidator(Validator):
             pass
 
 
-def validate(db, record):
+def validate(coll, record, schemas):
     """Validate a record for a given db
 
     Parameters
     ----------
-    db : str
+    coll : str
         The name of the db in question
     record : dict
         The record to be validated
+    schemas : dict
+        The schema to validate against
 
     Returns
     -------
@@ -776,6 +778,9 @@ def validate(db, record):
         The errors encountered (if any)
 
     """
-    schema = SCHEMAS[db]
-    v = NoDescriptionValidator(schema)
-    return v.validate(record), v.errors
+    if coll in schemas:
+        schema = schemas[coll]
+        v = NoDescriptionValidator(schema)
+        return v.validate(record), v.errors
+    else:
+        return True, ()
